@@ -1,5 +1,5 @@
 
-from tnorm.utilities.sage_types import *
+from tnorm.utilities.sage_types import Matrix
 #from sympy import Matrix as Matrix
 from tnorm.utilities.regina_helpers import get_oriented_quads, get_quads, in_cusp
 
@@ -38,8 +38,9 @@ def peripheral_curve_mats(M,T):
 
 ### Quad coordinate of the surface as a Matrix. Row i corresponds to tetrahedron i, and each row has
 ### six entries corresponding to the six quad types: (0,1), (2,3), (0,2), (1,3), (0,3), (1,2) in that order.
-def oriented_quads_mat(oriented_spun_surface):
-    s = oriented_spun_surface
+
+def oriented_quads_mat(qtons):
+    s = qtons
     T = s.triangulation()
     return Matrix([[get_oriented_quads(s,i,j,k) for (j,k) in [(0,1),(2,3),(0,2),(1,3),(0,3),(1,2)]] for i in range(T.size())])
 
@@ -55,8 +56,8 @@ def quads_mat(spun_surface):
 
 ### Same form as above matrix, but only picks up quads that have a boundary arc isotopic into the given
 ### cusp
-def quad_bdy_mat(oriented_spun_surface, cusp):
-    s = oriented_spun_surface
+def quad_bdy_mat(qtons, cusp):
+    s = qtons
     T = s.triangulation()
     quads_mat = []
     for i in range(T.size()):
@@ -72,62 +73,80 @@ def quad_bdy_mat(oriented_spun_surface, cusp):
 
 ### Matrix that encodes how curves intersect with quad types, restricted to intersections
 ### that contribute to the positive boundary (see Cooper--Tillmann--Worden Fig 5).def pos_intx_matrix():
-def pos_intersection_mat():
-    return Matrix([[0, 0, 0, 0, 0, 0],
-                   [1,0, 0, 0, 0, 0],
-                   [0, 0, 1,0, 0, 0],
-                   [0, 0, 0, 0, 1,0],
-                   [1,0, 0, 0, 0, 0],
-                   [0, 0, 0, 0, 0, 0],
-                   [0, 0, 0, 0,0, 1],
-                   [0, 0,0, 1, 0, 0],
-                   [0, 0, 1,0, 0, 0],
-                   [0, 0, 0, 0,0, 1],
-                   [0, 0, 0, 0, 0, 0],
-                   [0, 1, 0, 0, 0, 0],
-                   [0, 0, 0, 0, 1,0],
-                   [0, 0,0, 1, 0, 0],
-                   [0, 1, 0, 0, 0, 0],
-                   [0, 0, 0, 0, 0, 0]])
+
+POS_INTERSECTION_MAT = Matrix([[0, 0, 0, 0, 0, 0],
+                               [1,0, 0, 0, 0, 0],
+                               [0, 0, 1,0, 0, 0],
+                               [0, 0, 0, 0, 1,0],
+                               [1,0, 0, 0, 0, 0],
+                               [0, 0, 0, 0, 0, 0],
+                               [0, 0, 0, 0,0, 1],
+                               [0, 0,0, 1, 0, 0],
+                               [0, 0, 1,0, 0, 0],
+                               [0, 0, 0, 0,0, 1],
+                               [0, 0, 0, 0, 0, 0],
+                               [0, 1, 0, 0, 0, 0],
+                               [0, 0, 0, 0, 1,0],
+                               [0, 0,0, 1, 0, 0],
+                               [0, 1, 0, 0, 0, 0],
+                               [0, 0, 0, 0, 0, 0]])
 
 ### Matrix that encodes how curves intersect with quad types, restricted to intersections
 ### that contribute to the negative boundary (see Cooper--Tillmann--Worden Fig 5).
-def neg_intersection_mat():
-    return Matrix([[0, 0, 0, 0, 0, 0],
-                   [0,-1, 0, 0, 0, 0],
-                   [0, 0, 0,-1, 0, 0],
-                   [0, 0, 0, 0, 0,-1],
-                   [0,-1, 0, 0, 0, 0],
-                   [0, 0, 0, 0, 0, 0],
-                   [0, 0, 0, 0,-1, 0],
-                   [0, 0,-1, 0, 0, 0],
-                   [0, 0, 0,-1, 0, 0],
-                   [0, 0, 0, 0,-1, 0],
-                   [0, 0, 0, 0, 0, 0],
-                   [-1, 0, 0, 0, 0, 0],
-                   [0, 0, 0, 0, 0,-1],
-                   [0, 0,-1, 0, 0, 0],
-                   [-1, 0, 0, 0, 0, 0],
-                   [0, 0, 0, 0, 0, 0]])
+NEG_INTERSECTION_MAT = Matrix([[0, 0, 0, 0, 0, 0],
+                               [0,-1, 0, 0, 0, 0],
+                               [0, 0, 0,-1, 0, 0],
+                               [0, 0, 0, 0, 0,-1],
+                               [0,-1, 0, 0, 0, 0],
+                               [0, 0, 0, 0, 0, 0],
+                               [0, 0, 0, 0,-1, 0],
+                               [0, 0,-1, 0, 0, 0],
+                               [0, 0, 0,-1, 0, 0],
+                               [0, 0, 0, 0,-1, 0],
+                               [0, 0, 0, 0, 0, 0],
+                               [-1, 0, 0, 0, 0, 0],
+                               [0, 0, 0, 0, 0,-1],
+                               [0, 0,-1, 0, 0, 0],
+                               [-1, 0, 0, 0, 0, 0],
+                               [0, 0, 0, 0, 0, 0]])
 ### Matrix that encodes how curves intersect with quad types (see Cooper--Tillmann--Worden Fig 5).
-def intersection_mat():
-    return Matrix([[0, 0, 0, 0, 0, 0],
-                   [1,-1, 0, 0, 0, 0],
-                   [0, 0, 1,-1, 0, 0],
-                   [0, 0, 0, 0, 1,-1],
-                   [1,-1, 0, 0, 0, 0],
-                   [0, 0, 0, 0, 0, 0],
-                   [0, 0, 0, 0,-1, 1],
-                   [0, 0,-1, 1, 0, 0],
-                   [0, 0, 1,-1, 0, 0],
-                   [0, 0, 0, 0,-1, 1],
-                   [0, 0, 0, 0, 0, 0],
-                   [-1, 1, 0, 0, 0, 0],
-                   [0, 0, 0, 0, 1,-1],
-                   [0, 0,-1, 1, 0, 0],
-                   [-1, 1, 0, 0, 0, 0],
-                   [0, 0, 0, 0, 0, 0]])
-def dot_product(v,w):
-    return v.dot_product(w)
+INTERSECTION_MAT = Matrix([[0, 0, 0, 0, 0, 0],
+                           [1,-1, 0, 0, 0, 0],
+                           [0, 0, 1,-1, 0, 0],
+                           [0, 0, 0, 0, 1,-1],
+                           [1,-1, 0, 0, 0, 0],
+                           [0, 0, 0, 0, 0, 0],
+                           [0, 0, 0, 0,-1, 1],
+                           [0, 0,-1, 1, 0, 0],
+                           [0, 0, 1,-1, 0, 0],
+                           [0, 0, 0, 0,-1, 1],
+                           [0, 0, 0, 0, 0, 0],
+                           [-1, 1, 0, 0, 0, 0],
+                           [0, 0, 0, 0, 1,-1],
+                           [0, 0,-1, 1, 0, 0],
+                           [-1, 1, 0, 0, 0, 0],
+                           [0, 0, 0, 0, 0, 0]])
+
+### 
+UNORIENTED_INTERSECTION_MAT = Matrix([[0, 0, 0],
+                                      [1, 0, 0],
+                                      [0, 1, 0],
+                                      [0, 0, 1],
+                                      [1, 0, 0],
+                                      [0, 0, 0],
+                                      [0, 0, 1],
+                                      [0, 1, 0],
+                                      [0, 1, 0],
+                                      [0, 0, 1],
+                                      [0, 0, 0],
+                                      [1, 0, 0],
+                                      [0, 0, 1],
+                                      [0, 1, 0],
+                                      [1, 0, 0],
+                                      [0, 0, 0]])
+
+ABSNEG_INTERSECTION_MAT = NEG_INTERSECTION_MAT.apply_map(abs)
+
+
 
                   
\ No newline at end of file
