@@ -6,18 +6,19 @@ from sage.all import text3d
 from sage.all import Polyhedron
 from sage.all import gcd
 from sage.all import floor
-#from sage.all import Infinity
 from sage.all import n
 from sage.all import text
 from sage.all import RR
 from sage.all import VectorSpace
 from sage.all import QQ
-#from sage.all import lcm
 from sage.all import load_attach_path
-from sage.all import arctan
-from sage.all import arccos
 from sage.all import pi
-
-
-from sage.misc.misc import SAGE_TMP
+from sage.all import sin
+from sage.all import cos
+from sage.all import arccos
+from sage.all import arctan
+from sage.all import arcsin
+from sage.all import sqrt
+from sage.all import span
+from sage.all import Graph
 
